@@ -34,7 +34,8 @@ public:
     Tuner(int height, QObject * parent);
     int centre();
     int deviation();
-    bool mouseEvent(QEvent::Type, QMouseEvent event);
+    bool mouseEvent(QEvent::Type, QMouseEvent *event);
+    void leaveEvent();
     void paintFront(QPainter &painter, QRect &rect, range_t<size_t> sampleRange);
     void setCentre(int centre);
     void setDeviation(int dev);
